@@ -25,7 +25,7 @@ class GSPeerConnectionWatcher:
             return frame
 
     @classmethod
-    async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None, ontrackterminate=None):
+    async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None, ontrackended=None):
         self = GSPeerConnectionWatcher()
         self.rtconfiList = []
         self.sio = socketio.AsyncClient()
@@ -34,7 +34,7 @@ class GSPeerConnectionWatcher:
         self.target = target
         self.onmessage = onmessage
         self.ontrack = ontrack
-        self.ontrackterminate = ontrackterminate
+        self.ontrackended = ontrackended
         self.logger = logging.getLogger(__name__)
 
         if self.gsdbs.credentials["stunenable"]:
@@ -78,7 +78,7 @@ class GSPeerConnectionWatcher:
 
                 @track.on("ended")
                 async def on_ended():
-                    self.ontrackterminate(self.gsdbs, self.target)
+                    self.ontrackended(self.gsdbs, self.target)
 
             await self.peerConnections.setLocalDescription(await self.peerConnections.createOffer())
             await self.sio.emit("watcher",
